package com.muyu.common.domian;

import com.baomidou.mybatisplus.annotation.TableName;
import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.common.domian.req.NodeAddReq;
import com.muyu.common.domian.req.NodeUpdReq;
import com.muyu.common.domian.req.TaskInfoAddReq;
import com.muyu.common.domian.resp.NodeResp;
import com.muyu.common.domian.resp.TaskInfoResp;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.util.function.Supplier;

@EqualsAndHashCode(callSuper = true)
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@TableName(value = "etl_node" ,autoResultMap = true)
public class Node extends BaseEntity {

    /**
     * 节点id
     */
    private Integer id;

    /**
     * 节点名称
     */
    private String nodeName;

    /**
     * 任务id(taskInfo)
     */
    private Integer taskId;

    /**
     * 数据库id
     */
    private String databaseId;

    /**
     * 表名称
     */
    private String tableName;

    /**
     * 表别名
     */
    private String tableAsName;

    /**
     * 表字段
     */
    private String tableField;

    /**
     * 表字段别名
     */
    private String tableAsField;

    /**
     * 字段规则
     */
    private String fieldAsEngineId;

    public static NodeResp build(Node node) {
        return NodeResp.builder()
                .id(node.id)
                .nodeName(node.nodeName)
                .taskId(node.taskId)
                .databaseId(node.databaseId)
                .tableName(node.tableName)
                .tableAsName(node.tableAsName)
                .tableField(node.tableField)
                .tableAsField(node.getTableField())
                .fieldAsEngineId(node.fieldAsEngineId)
                .build();
    }

    public static Node addBuild(NodeAddReq req) {
        return Node.builder()
                .nodeName(req.getNodeName())
                .taskId(req.getTaskId())
                .databaseId(req.getDatabaseId())
                .tableName(req.getTableName())
                .tableAsName(req.getTableAsName())
                .tableField(req.getTableField())
                .tableAsField(req.getTableAsField())
                .fieldAsEngineId(req.getFieldAsEngineId())
                .build();
    }
    public static Node updBuild(NodeUpdReq req, Supplier<Integer> id) {
        return Node.builder()
                .id(id.get())
                .nodeName(req.getNodeName())
                .taskId(req.getTaskId())
                .databaseId(req.getDatabaseId())
                .tableName(req.getTableName())
                .tableAsName(req.getTableAsName())
                .tableField(req.getTableField())
                .tableAsField(req.getTableAsField())
                .fieldAsEngineId(req.getFieldAsEngineId())
                .build();
    }
}
